Class: Google::Cloud::Security::PrivateCA::V1::CertificateAuthority::UserDefinedAccessUrls

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/security/privateca/v1/resources.rb

Overview

User-defined URLs for accessing content published by this CertificateAuthority.

Instance Attribute Summary collapse

Instance Attribute Details

#aia_issuing_certificate_urls::Array<::String>

Returns Optional. A list of URLs where the issuer CA certificate may be downloaded, which appears in the "Authority Information Access" extension in the certificate. If specified, the default [Cloud Storage URLs][google.cloud.security.privateca.v1.CertificateAuthority.AccessUrls.ca_certificate_access_url] will be omitted.

Returns:

  • (::Array<::String>)

    Optional. A list of URLs where the issuer CA certificate may be downloaded, which appears in the "Authority Information Access" extension in the certificate. If specified, the default [Cloud Storage URLs][google.cloud.security.privateca.v1.CertificateAuthority.AccessUrls.ca_certificate_access_url] will be omitted.



212
213
214
215
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 212

class UserDefinedAccessUrls
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#crl_access_urls::Array<::String>

Returns Optional. A list of URLs where to obtain CRL information, i.e. the DistributionPoint.fullName described by https://tools.ietf.org/html/rfc5280#section-4.2.1.13. If specified, the default [Cloud Storage URLs][google.cloud.security.privateca.v1.CertificateAuthority.AccessUrls.crl_access_urls] will be omitted.

Returns:

  • (::Array<::String>)

    Optional. A list of URLs where to obtain CRL information, i.e. the DistributionPoint.fullName described by https://tools.ietf.org/html/rfc5280#section-4.2.1.13. If specified, the default [Cloud Storage URLs][google.cloud.security.privateca.v1.CertificateAuthority.AccessUrls.crl_access_urls] will be omitted.



212
213
214
215
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 212

class UserDefinedAccessUrls
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end