Class: Google::Cloud::Security::PrivateCA::V1::FetchCaCertsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Security::PrivateCA::V1::FetchCaCertsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/security/privateca/v1/service.rb
Overview
Response message for CertificateAuthorityService.FetchCaCerts.
Defined Under Namespace
Classes: CertChain
Instance Attribute Summary collapse
-
#ca_certs ⇒ ::Array<::Google::Cloud::Security::PrivateCA::V1::FetchCaCertsResponse::CertChain>
The PEM encoded CA certificate chains of all certificate authorities in this CaPool in the ENABLED, DISABLED, or STAGED states.
Instance Attribute Details
#ca_certs ⇒ ::Array<::Google::Cloud::Security::PrivateCA::V1::FetchCaCertsResponse::CertChain>
Returns The PEM encoded CA certificate chains of all certificate authorities in this CaPool in the ENABLED, DISABLED, or STAGED states.
681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'proto_docs/google/cloud/security/privateca/v1/service.rb', line 681 class FetchCaCertsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] certificates # @return [::Array<::String>] # The certificates that form the CA chain, from leaf to root order. class CertChain include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |