Class: Google::Cloud::Security::PrivateCA::V1::ListCertificatesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/security/privateca/v1/service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Only include resources that match the filter in the response. For details on supported filters and syntax, see Certificates Filtering documentation.

Returns:



148
149
150
151
# File 'proto_docs/google/cloud/security/privateca/v1/service.rb', line 148

class ListCertificatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Specify how the results should be sorted. For details on supported fields and syntax, see Certificates Sorting documentation.

Returns:



148
149
150
151
# File 'proto_docs/google/cloud/security/privateca/v1/service.rb', line 148

class ListCertificatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Limit on the number of Certificates to include in the response. Further Certificates can subsequently be obtained by including the ListCertificatesResponse.next_page_token in a subsequent request. If unspecified, the server will pick an appropriate default.

Returns:



148
149
150
151
# File 'proto_docs/google/cloud/security/privateca/v1/service.rb', line 148

class ListCertificatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Pagination token, returned earlier via ListCertificatesResponse.next_page_token.

Returns:



148
149
150
151
# File 'proto_docs/google/cloud/security/privateca/v1/service.rb', line 148

class ListCertificatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the parent associated with the Certificates, in the format projects/*/locations/*/caPools/*. The parent resource name can be in one of two forms:

  1. Specific CA Pool: To list certificates within a single CA Pool: projects/*/locations/*/caPools/*

  2. All CA Pools in a Location: To list certificates across all CA Pools in a given project and location, use the wildcard character (-) in place of the CA Pool ID. Example: projects/*/locations/*/caPools/-.

Returns:

  • (::String)

    Required. The resource name of the parent associated with the Certificates, in the format projects/*/locations/*/caPools/*. The parent resource name can be in one of two forms:

    1. Specific CA Pool: To list certificates within a single CA Pool: projects/*/locations/*/caPools/*

    2. All CA Pools in a Location: To list certificates across all CA Pools in a given project and location, use the wildcard character (-) in place of the CA Pool ID. Example: projects/*/locations/*/caPools/-



148
149
150
151
# File 'proto_docs/google/cloud/security/privateca/v1/service.rb', line 148

class ListCertificatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end