Class: Google::Cloud::Security::PrivateCA::V1::X509Parameters::CaOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/security/privateca/v1/resources.rb

Overview

Describes the X.509 basic constraints extension, per RFC 5280 section 4.2.1.9

Instance Attribute Summary collapse

Instance Attribute Details

#is_ca::Boolean

Returns Optional. Refers to the "CA" boolean field in the X.509 extension. When this value is missing, the basic constraints extension will be omitted from the certificate.

Returns:

  • (::Boolean)

    Optional. Refers to the "CA" boolean field in the X.509 extension. When this value is missing, the basic constraints extension will be omitted from the certificate.



1003
1004
1005
1006
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1003

class CaOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_issuer_path_length::Integer

Returns Optional. Refers to the path length constraint field in the X.509 extension. For a CA certificate, this value describes the depth of subordinate CA certificates that are allowed. If this value is less than 0, the request will fail. If this value is missing, the max path length will be omitted from the certificate.

Returns:

  • (::Integer)

    Optional. Refers to the path length constraint field in the X.509 extension. For a CA certificate, this value describes the depth of subordinate CA certificates that are allowed. If this value is less than 0, the request will fail. If this value is missing, the max path length will be omitted from the certificate.



1003
1004
1005
1006
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1003

class CaOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end