Class: Google::Cloud::Security::PrivateCA::V1::Certificate
- Inherits:
-
Object
- Object
- Google::Cloud::Security::PrivateCA::V1::Certificate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/security/privateca/v1/resources.rb
Overview
A Certificate corresponds to a signed X.509 certificate issued by a CertificateAuthority.
Defined Under Namespace
Classes: LabelsEntry, RevocationDetails
Instance Attribute Summary collapse
-
#certificate_description ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateDescription
readonly
Output only.
-
#certificate_template ⇒ ::String
Immutable.
-
#config ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateConfig
Immutable.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#issuer_certificate_authority ⇒ ::String
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#lifetime ⇒ ::Google::Protobuf::Duration
Required.
-
#name ⇒ ::String
Identifier.
-
#pem_certificate ⇒ ::String
readonly
Output only.
-
#pem_certificate_chain ⇒ ::Array<::String>
readonly
Output only.
-
#pem_csr ⇒ ::String
Immutable.
-
#requested_not_before_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#revocation_details ⇒ ::Google::Cloud::Security::PrivateCA::V1::Certificate::RevocationDetails
readonly
Output only.
-
#subject_mode ⇒ ::Google::Cloud::Security::PrivateCA::V1::SubjectRequestMode
Immutable.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#certificate_description ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateDescription (readonly)
Returns Output only. A structured description of the issued X.509 certificate.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#certificate_template ⇒ ::String
Returns Immutable. The resource name for a
CertificateTemplate
used to issue this certificate, in the format
projects/*/locations/*/certificateTemplates/*.
If this is specified, the caller must have the necessary permission to
use this template. If this is omitted, no template will be used.
This template must be in the same location as the
Certificate.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#config ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateConfig
Returns Immutable. A description of the certificate and key that does not require X.509 or ASN.1.
Note: The following fields are mutually exclusive: config, pem_csr. If a field in that set is populated, all other fields in the set will automatically be cleared.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which this Certificate was created.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#issuer_certificate_authority ⇒ ::String (readonly)
Returns Output only. The resource name of the issuing
CertificateAuthority
in the format projects/*/locations/*/caPools/*/certificateAuthorities/*.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels with user-defined metadata.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#lifetime ⇒ ::Google::Protobuf::Duration
Returns Required. Immutable. The desired lifetime of a certificate. Used to create the "not_before_time" and "not_after_time" fields inside an X.509 certificate. Note that the lifetime may be truncated if it would extend past the life of any certificate authority in the issuing chain.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The resource name for this
Certificate in the format
projects/*/locations/*/caPools/*/certificates/*.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pem_certificate ⇒ ::String (readonly)
Returns Output only. The pem-encoded, signed X.509 certificate.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pem_certificate_chain ⇒ ::Array<::String> (readonly)
Returns Output only. The chain that may be used to verify the X.509 certificate. Expected to be in issuer-to-root order according to RFC 5246.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pem_csr ⇒ ::String
Returns Immutable. A pem-encoded X.509 certificate signing request (CSR).
Note: The following fields are mutually exclusive: pem_csr, config. If a field in that set is populated, all other fields in the set will automatically be cleared.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#requested_not_before_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. The requested not_before_time of this Certificate. This field may only be set if the CaPool.IssuancePolicy.allow_requester_specified_not_before_time field is set to true for the issuing CaPool.
If this field is specified, the certificate will be issued with this 'not_before_time'. If this is not specified, the 'not_before_time' will be set to the issuance time or issuance time minus backdate_duration depending on the CaPool configuration.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#revocation_details ⇒ ::Google::Cloud::Security::PrivateCA::V1::Certificate::RevocationDetails (readonly)
Returns Output only. Details regarding the revocation of this Certificate. This Certificate is considered revoked if and only if this field is present.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#subject_mode ⇒ ::Google::Cloud::Security::PrivateCA::V1::SubjectRequestMode
Returns Immutable. Specifies how the
Certificate's identity
fields are to be decided. If this is omitted, the DEFAULT subject mode
will be used.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which this Certificate was updated.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 832 class Certificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes fields that are relavent to the revocation of a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_state # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # Indicates why a # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. # @!attribute [rw] revocation_time # @return [::Google::Protobuf::Timestamp] # The time at which this # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevocationDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |