Class: Google::Cloud::Security::PrivateCA::V1::CertificateConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Security::PrivateCA::V1::CertificateConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/security/privateca/v1/resources.rb
Overview
A CertificateConfig describes an X.509 certificate or CSR that is to be created, as an alternative to using ASN.1.
Defined Under Namespace
Classes: KeyId, SubjectConfig
Instance Attribute Summary collapse
-
#public_key ⇒ ::Google::Cloud::Security::PrivateCA::V1::PublicKey
Optional.
-
#subject_config ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateConfig::SubjectConfig
Required.
-
#subject_key_id ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateConfig::KeyId
Optional.
-
#x509_config ⇒ ::Google::Cloud::Security::PrivateCA::V1::X509Parameters
Required.
Instance Attribute Details
#public_key ⇒ ::Google::Cloud::Security::PrivateCA::V1::PublicKey
Returns Optional. The public key that corresponds to this config. This is, for example, used when issuing Certificates, but not when creating a self-signed CertificateAuthority or CertificateAuthority CSR.
1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1167 class CertificateConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # These values are used to create the distinguished name and subject # alternative name fields in an X.509 certificate. # @!attribute [rw] subject # @return [::Google::Cloud::Security::PrivateCA::V1::Subject] # Optional. Contains distinguished name fields such as the common name, # location and organization. # @!attribute [rw] subject_alt_name # @return [::Google::Cloud::Security::PrivateCA::V1::SubjectAltNames] # Optional. The subject alternative name fields. class SubjectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A KeyId identifies a specific public key, usually by hashing the public # key. # @!attribute [rw] key_id # @return [::String] # Required. The value of this KeyId encoded in lowercase hexadecimal. This # is most likely the 160 bit SHA-1 hash of the public key. class KeyId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#subject_config ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateConfig::SubjectConfig
Returns Required. Specifies some of the values in a certificate that are related to the subject.
1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1167 class CertificateConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # These values are used to create the distinguished name and subject # alternative name fields in an X.509 certificate. # @!attribute [rw] subject # @return [::Google::Cloud::Security::PrivateCA::V1::Subject] # Optional. Contains distinguished name fields such as the common name, # location and organization. # @!attribute [rw] subject_alt_name # @return [::Google::Cloud::Security::PrivateCA::V1::SubjectAltNames] # Optional. The subject alternative name fields. class SubjectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A KeyId identifies a specific public key, usually by hashing the public # key. # @!attribute [rw] key_id # @return [::String] # Required. The value of this KeyId encoded in lowercase hexadecimal. This # is most likely the 160 bit SHA-1 hash of the public key. class KeyId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#subject_key_id ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateConfig::KeyId
Returns Optional. When specified this provides a custom SKI to be used in the certificate. This should only be used to maintain a SKI of an existing CA originally created outside CA service, which was not generated using method (1) described in RFC 5280 section 4.2.1.2.
1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1167 class CertificateConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # These values are used to create the distinguished name and subject # alternative name fields in an X.509 certificate. # @!attribute [rw] subject # @return [::Google::Cloud::Security::PrivateCA::V1::Subject] # Optional. Contains distinguished name fields such as the common name, # location and organization. # @!attribute [rw] subject_alt_name # @return [::Google::Cloud::Security::PrivateCA::V1::SubjectAltNames] # Optional. The subject alternative name fields. class SubjectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A KeyId identifies a specific public key, usually by hashing the public # key. # @!attribute [rw] key_id # @return [::String] # Required. The value of this KeyId encoded in lowercase hexadecimal. This # is most likely the 160 bit SHA-1 hash of the public key. class KeyId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#x509_config ⇒ ::Google::Cloud::Security::PrivateCA::V1::X509Parameters
Returns Required. Describes how some of the technical X.509 fields in a certificate should be populated.
1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1167 class CertificateConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # These values are used to create the distinguished name and subject # alternative name fields in an X.509 certificate. # @!attribute [rw] subject # @return [::Google::Cloud::Security::PrivateCA::V1::Subject] # Optional. Contains distinguished name fields such as the common name, # location and organization. # @!attribute [rw] subject_alt_name # @return [::Google::Cloud::Security::PrivateCA::V1::SubjectAltNames] # Optional. The subject alternative name fields. class SubjectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A KeyId identifies a specific public key, usually by hashing the public # key. # @!attribute [rw] key_id # @return [::String] # Required. The value of this KeyId encoded in lowercase hexadecimal. This # is most likely the 160 bit SHA-1 hash of the public key. class KeyId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |