Class: Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList
- Inherits:
-
Object
- Object
- Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/security/privateca/v1/resources.rb
Overview
A CertificateRevocationList corresponds to a signed X.509 certificate Revocation List (CRL). A CRL contains the serial numbers of certificates that should no longer be trusted.
Defined Under Namespace
Modules: State Classes: LabelsEntry, RevokedCertificate
Instance Attribute Summary collapse
-
#access_url ⇒ ::String
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#pem_crl ⇒ ::String
readonly
Output only.
-
#revision_id ⇒ ::String
readonly
Output only.
-
#revoked_certificates ⇒ ::Array<::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList::RevokedCertificate>
readonly
Output only.
-
#sequence_number ⇒ ::Integer
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList::State
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#access_url ⇒ ::String (readonly)
Returns Output only. The location where 'pem_crl' can be accessed.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which this CertificateRevocationList was created.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels with user-defined metadata.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |
#name ⇒ ::String
Returns Identifier. The resource name for this
CertificateRevocationList
in the format projects/*/locations/*/caPools/*certificateAuthorities/*/
certificateRevocationLists/*.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |
#pem_crl ⇒ ::String (readonly)
Returns Output only. The PEM-encoded X.509 CRL.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |
#revision_id ⇒ ::String (readonly)
Returns Output only. The revision ID of this CertificateRevocationList. A new revision is committed whenever a new CRL is published. The format is an 8-character hexadecimal string.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |
#revoked_certificates ⇒ ::Array<::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList::RevokedCertificate> (readonly)
Returns Output only. The revoked serial numbers that appear in pem_crl.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |
#sequence_number ⇒ ::Integer (readonly)
Returns Output only. The CRL sequence number that appears in pem_crl.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |
#state ⇒ ::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList::State (readonly)
Returns Output only. The State for this CertificateRevocationList.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which this CertificateRevocationList was updated.
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 690 class CertificateRevocationList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes a revoked # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] certificate # @return [::String] # The resource name for the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} in the # format `projects/*/locations/*/caPools/*/certificates/*`. # @!attribute [rw] hex_serial_number # @return [::String] # The serial number of the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate}. # @!attribute [rw] revocation_reason # @return [::Google::Cloud::Security::PrivateCA::V1::RevocationReason] # The reason the # {::Google::Cloud::Security::PrivateCA::V1::Certificate Certificate} was # revoked. class RevokedCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of a # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList}, # indicating if it is current. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is up to date. ACTIVE = 1 # The # {::Google::Cloud::Security::PrivateCA::V1::CertificateRevocationList CertificateRevocationList} # is no longer current. SUPERSEDED = 2 end end |