Class: Google::Cloud::Security::PrivateCA::V1::KeyUsage
- Inherits:
-
Object
- Object
- Google::Cloud::Security::PrivateCA::V1::KeyUsage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/security/privateca/v1/resources.rb
Overview
A KeyUsage describes key usage values that may appear in an X.509 certificate.
Defined Under Namespace
Classes: ExtendedKeyUsageOptions, KeyUsageOptions
Instance Attribute Summary collapse
-
#base_key_usage ⇒ ::Google::Cloud::Security::PrivateCA::V1::KeyUsage::KeyUsageOptions
Describes high-level ways in which a key may be used.
-
#extended_key_usage ⇒ ::Google::Cloud::Security::PrivateCA::V1::KeyUsage::ExtendedKeyUsageOptions
Detailed scenarios in which a key may be used.
-
#unknown_extended_key_usages ⇒ ::Array<::Google::Cloud::Security::PrivateCA::V1::ObjectId>
Used to describe extended key usages that are not listed in the KeyUsage.ExtendedKeyUsageOptions message.
Instance Attribute Details
#base_key_usage ⇒ ::Google::Cloud::Security::PrivateCA::V1::KeyUsage::KeyUsageOptions
Returns Describes high-level ways in which a key may be used.
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1335 class KeyUsage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # {::Google::Cloud::Security::PrivateCA::V1::KeyUsage::KeyUsageOptions KeyUsage.KeyUsageOptions} # corresponds to the key usage values described in # https://tools.ietf.org/html/rfc5280#section-4.2.1.3. # @!attribute [rw] digital_signature # @return [::Boolean] # The key may be used for digital signatures. # @!attribute [rw] content_commitment # @return [::Boolean] # The key may be used for cryptographic commitments. Note that this may # also be referred to as "non-repudiation". # @!attribute [rw] key_encipherment # @return [::Boolean] # The key may be used to encipher other keys. # @!attribute [rw] data_encipherment # @return [::Boolean] # The key may be used to encipher data. # @!attribute [rw] key_agreement # @return [::Boolean] # The key may be used in a key agreement protocol. # @!attribute [rw] cert_sign # @return [::Boolean] # The key may be used to sign certificates. # @!attribute [rw] crl_sign # @return [::Boolean] # The key may be used sign certificate revocation lists. # @!attribute [rw] encipher_only # @return [::Boolean] # The key may be used to encipher only. # @!attribute [rw] decipher_only # @return [::Boolean] # The key may be used to decipher only. class KeyUsageOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # {::Google::Cloud::Security::PrivateCA::V1::KeyUsage::ExtendedKeyUsageOptions KeyUsage.ExtendedKeyUsageOptions} # has fields that correspond to certain common OIDs that could be specified # as an extended key usage value. # @!attribute [rw] server_auth # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.1. Officially described as "TLS WWW # server authentication", though regularly used for non-WWW TLS. # @!attribute [rw] client_auth # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.2. Officially described as "TLS WWW # client authentication", though regularly used for non-WWW TLS. # @!attribute [rw] code_signing # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.3. Officially described as "Signing of # downloadable executable code client authentication". # @!attribute [rw] email_protection # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.4. Officially described as "Email # protection". # @!attribute [rw] time_stamping # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.8. Officially described as "Binding # the hash of an object to a time". # @!attribute [rw] ocsp_signing # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.9. Officially described as "Signing # OCSP responses". class ExtendedKeyUsageOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#extended_key_usage ⇒ ::Google::Cloud::Security::PrivateCA::V1::KeyUsage::ExtendedKeyUsageOptions
Returns Detailed scenarios in which a key may be used.
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1335 class KeyUsage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # {::Google::Cloud::Security::PrivateCA::V1::KeyUsage::KeyUsageOptions KeyUsage.KeyUsageOptions} # corresponds to the key usage values described in # https://tools.ietf.org/html/rfc5280#section-4.2.1.3. # @!attribute [rw] digital_signature # @return [::Boolean] # The key may be used for digital signatures. # @!attribute [rw] content_commitment # @return [::Boolean] # The key may be used for cryptographic commitments. Note that this may # also be referred to as "non-repudiation". # @!attribute [rw] key_encipherment # @return [::Boolean] # The key may be used to encipher other keys. # @!attribute [rw] data_encipherment # @return [::Boolean] # The key may be used to encipher data. # @!attribute [rw] key_agreement # @return [::Boolean] # The key may be used in a key agreement protocol. # @!attribute [rw] cert_sign # @return [::Boolean] # The key may be used to sign certificates. # @!attribute [rw] crl_sign # @return [::Boolean] # The key may be used sign certificate revocation lists. # @!attribute [rw] encipher_only # @return [::Boolean] # The key may be used to encipher only. # @!attribute [rw] decipher_only # @return [::Boolean] # The key may be used to decipher only. class KeyUsageOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # {::Google::Cloud::Security::PrivateCA::V1::KeyUsage::ExtendedKeyUsageOptions KeyUsage.ExtendedKeyUsageOptions} # has fields that correspond to certain common OIDs that could be specified # as an extended key usage value. # @!attribute [rw] server_auth # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.1. Officially described as "TLS WWW # server authentication", though regularly used for non-WWW TLS. # @!attribute [rw] client_auth # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.2. Officially described as "TLS WWW # client authentication", though regularly used for non-WWW TLS. # @!attribute [rw] code_signing # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.3. Officially described as "Signing of # downloadable executable code client authentication". # @!attribute [rw] email_protection # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.4. Officially described as "Email # protection". # @!attribute [rw] time_stamping # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.8. Officially described as "Binding # the hash of an object to a time". # @!attribute [rw] ocsp_signing # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.9. Officially described as "Signing # OCSP responses". class ExtendedKeyUsageOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unknown_extended_key_usages ⇒ ::Array<::Google::Cloud::Security::PrivateCA::V1::ObjectId>
Returns Used to describe extended key usages that are not listed in the KeyUsage.ExtendedKeyUsageOptions message.
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1335 class KeyUsage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # {::Google::Cloud::Security::PrivateCA::V1::KeyUsage::KeyUsageOptions KeyUsage.KeyUsageOptions} # corresponds to the key usage values described in # https://tools.ietf.org/html/rfc5280#section-4.2.1.3. # @!attribute [rw] digital_signature # @return [::Boolean] # The key may be used for digital signatures. # @!attribute [rw] content_commitment # @return [::Boolean] # The key may be used for cryptographic commitments. Note that this may # also be referred to as "non-repudiation". # @!attribute [rw] key_encipherment # @return [::Boolean] # The key may be used to encipher other keys. # @!attribute [rw] data_encipherment # @return [::Boolean] # The key may be used to encipher data. # @!attribute [rw] key_agreement # @return [::Boolean] # The key may be used in a key agreement protocol. # @!attribute [rw] cert_sign # @return [::Boolean] # The key may be used to sign certificates. # @!attribute [rw] crl_sign # @return [::Boolean] # The key may be used sign certificate revocation lists. # @!attribute [rw] encipher_only # @return [::Boolean] # The key may be used to encipher only. # @!attribute [rw] decipher_only # @return [::Boolean] # The key may be used to decipher only. class KeyUsageOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # {::Google::Cloud::Security::PrivateCA::V1::KeyUsage::ExtendedKeyUsageOptions KeyUsage.ExtendedKeyUsageOptions} # has fields that correspond to certain common OIDs that could be specified # as an extended key usage value. # @!attribute [rw] server_auth # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.1. Officially described as "TLS WWW # server authentication", though regularly used for non-WWW TLS. # @!attribute [rw] client_auth # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.2. Officially described as "TLS WWW # client authentication", though regularly used for non-WWW TLS. # @!attribute [rw] code_signing # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.3. Officially described as "Signing of # downloadable executable code client authentication". # @!attribute [rw] email_protection # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.4. Officially described as "Email # protection". # @!attribute [rw] time_stamping # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.8. Officially described as "Binding # the hash of an object to a time". # @!attribute [rw] ocsp_signing # @return [::Boolean] # Corresponds to OID 1.3.6.1.5.5.7.3.9. Officially described as "Signing # OCSP responses". class ExtendedKeyUsageOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |