Class: Google::Cloud::Security::PrivateCA::V1::PublicKey
- Inherits:
-
Object
- Object
- Google::Cloud::Security::PrivateCA::V1::PublicKey
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/security/privateca/v1/resources.rb
Overview
A PublicKey describes a public key.
Defined Under Namespace
Modules: KeyFormat
Instance Attribute Summary collapse
-
#format ⇒ ::Google::Cloud::Security::PrivateCA::V1::PublicKey::KeyFormat
Required.
-
#key ⇒ ::String
Required.
Instance Attribute Details
#format ⇒ ::Google::Cloud::Security::PrivateCA::V1::PublicKey::KeyFormat
Returns Required. The format of the public key.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1113 class PublicKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of public keys formats that are supported. Currently, only `PEM` # format is supported. module KeyFormat # Default unspecified value. KEY_FORMAT_UNSPECIFIED = 0 # The key is PEM-encoded as defined in [RFC # 7468](https://tools.ietf.org/html/rfc7468). It can be any of the # following: a PEM-encoded PKCS#1/RFC 3447 RSAPublicKey # structure, an RFC 5280 # [SubjectPublicKeyInfo](https://tools.ietf.org/html/rfc5280#section-4.1) # or a PEM-encoded X.509 certificate signing request (CSR). If a # [SubjectPublicKeyInfo](https://tools.ietf.org/html/rfc5280#section-4.1) # is specified, it can contain a A PEM-encoded PKCS#1/RFC 3447 RSAPublicKey # or a NIST P-256/secp256r1/prime256v1 or P-384 key. If a CSR is specified, # it will used solely for the purpose of extracting the public key. When # generated by the service, it will always be an RFC 5280 # [SubjectPublicKeyInfo](https://tools.ietf.org/html/rfc5280#section-4.1) # structure containing an algorithm identifier and a key. PEM = 1 end end |
#key ⇒ ::String
Returns Required. A public key. The padding and encoding
must match with the KeyFormat value specified for the format field.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'proto_docs/google/cloud/security/privateca/v1/resources.rb', line 1113 class PublicKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of public keys formats that are supported. Currently, only `PEM` # format is supported. module KeyFormat # Default unspecified value. KEY_FORMAT_UNSPECIFIED = 0 # The key is PEM-encoded as defined in [RFC # 7468](https://tools.ietf.org/html/rfc7468). It can be any of the # following: a PEM-encoded PKCS#1/RFC 3447 RSAPublicKey # structure, an RFC 5280 # [SubjectPublicKeyInfo](https://tools.ietf.org/html/rfc5280#section-4.1) # or a PEM-encoded X.509 certificate signing request (CSR). If a # [SubjectPublicKeyInfo](https://tools.ietf.org/html/rfc5280#section-4.1) # is specified, it can contain a A PEM-encoded PKCS#1/RFC 3447 RSAPublicKey # or a NIST P-256/secp256r1/prime256v1 or P-384 key. If a CSR is specified, # it will used solely for the purpose of extracting the public key. When # generated by the service, it will always be an RFC 5280 # [SubjectPublicKeyInfo](https://tools.ietf.org/html/rfc5280#section-4.1) # structure containing an algorithm identifier and a key. PEM = 1 end end |